| Type: | Package |
| Title: | Optimized Ensemble Predictor for 'C' and 'A' Methylation in Organism |
| Version: | 0.1.1 |
| Author: | Abhik Sarkar [aut, cre], Dipro Sinha [aut], Sneha Murmu [aut], Md Yeasin [aut], Dwijesh Chandra Mishra [aut], Sunil Archak [aut] |
| Maintainer: | Abhik Sarkar <abhik.iasri@gmail.com> |
| Description: | DNA methylation is an important epigenetic process that regulates gene activity through chemical modifications of DNA without changing its sequence. 'OpEnCAMeO' is a organism based ensemble model for prediction of 4mC, 6mA and No methylation sites directly from DNA sequences. It combines multiple machine learning algorithms trained on Bacteria (Escherichia coli), Fungi (Saccharomyces cerevisiae) and Nematode (Caenorhabditis elegans) as reference models to deliver accurate predictions. This methodology is being inspired by the ensemble algorithm for methylation prediction developed by Sinha et al. (2025) <doi:10.1101/2025.11.10.687509>. |
| Imports: | Biostrings, seqinr, stringr, tibble, entropy, ftrCOOL, stats, elmNNRcpp |
| Suggests: | caret, kernlab, ranger, xgboost, gbm |
| Encoding: | UTF-8 |
| License: | GPL-3 |
| Config/roxygen2/version: | 8.0.0 |
| NeedsCompilation: | no |
| Packaged: | 2026-07-22 09:37:45 UTC; Abhik |
| Repository: | CRAN |
| Date/Publication: | 2026-07-30 17:40:22 UTC |
DNA Methylation Prediction in Bacteria
Description
Predicting sequences with DNA methylation sites like 4mC or 6mA based on Escherichia coli as reference model.
Usage
Bacteria_MethPred(fasta_file_path, Reference = "E.Coli")
Arguments
fasta_file_path |
Sequence file (.fasta format) |
Reference |
Escherichia coli as Reference Model for Bacteria |
Value
Methylation Status: Sequences with their probable DNA methylation state such as 4mC, 6mA or Non Methhylated.
References
Lv, H., Dao, F. Y., Zhang, D., Guan, Z. X., Yang, H., Su, W., ... & Lin, H. (2020). iDNA-MS: an integrated computational tool for detecting DNA modification sites in multiple genomes. Iscience, 23(4).
Examples
library(OpEnCAMeO)
data<-system.file("exdata/test.fasta", package = "OpEnCAMeO")
pred<-Bacteria_MethPred(fasta_file_path=data, Reference="E.Coli")
DNA Methylation Prediction in Fungi
Description
Predicting sequences with DNA methylation sites like 4mC or 6mA based on Saccharomyces cerevisiae as reference model.
Usage
Fungi_MethPred(fasta_file_path, Reference = "S.cerevisiae")
Arguments
fasta_file_path |
Sequence file (.fasta format) |
Reference |
Saccharomyces cerevisiae as Reference Model for Fungi |
Value
Methylation Status: Sequences with their probable DNA methylation state such as 4mC, 6mA or Non Methhylated.
References
Lv, H., Dao, F. Y., Zhang, D., Guan, Z. X., Yang, H., Su, W., ... & Lin, H. (2020). iDNA-MS: an integrated computational tool for detecting DNA modification sites in multiple genomes. Iscience, 23(4).
Examples
library(OpEnCAMeO)
data<-system.file("exdata/test.fasta", package = "OpEnCAMeO")
pred<-Fungi_MethPred(fasta_file_path=data, Reference="S.cerevisiae")
DNA Methylation Prediction in Nematode
Description
Predicting sequences with DNA methylation sites like 4mC or 6mA based on Caenorhabditis elegans as reference model.
Usage
Nematode_MethPred(fasta_file_path, Reference = "C.elegans")
Arguments
fasta_file_path |
Sequence file (.fasta format) |
Reference |
Caenorhabditis elegansis as Reference Model for Nematodes |
Value
Methylation Status: Sequences with their probable DNA methylation state such as 4mC, 6mA or Non Methhylated.
References
Lv, H., Dao, F. Y., Zhang, D., Guan, Z. X., Yang, H., Su, W., ... & Lin, H. (2020). iDNA-MS: an integrated computational tool for detecting DNA modification sites in multiple genomes. Iscience, 23(4).
Examples
library(OpEnCAMeO)
data<-system.file("exdata/test.fasta", package = "OpEnCAMeO")
pred<-Nematode_MethPred(fasta_file_path=data, Reference="C.elegans")